@@ -9,7 +9,7 @@ load_dotenv()
 from google.cloud import bigquery
 from google.oauth2 import service_account
 from google.cloud.exceptions import NotFound
-from data_connectors import Transform
+from .transform import Transform
 
 class BigQuery:
 
